guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

06/06: gnu: imv: Record absolute file name of 'imv' script.


From: guix-commits
Subject: 06/06: gnu: imv: Record absolute file name of 'imv' script.
Date: Sun, 5 Feb 2023 08:03:45 -0500 (EST)

lfam pushed a commit to branch master
in repository guix.

commit ce28d14a9cdc2002b48acfe1b1bb627bc6a9c9d8
Author: Timotej Lazar <timotej.lazar@araneo.si>
AuthorDate: Sun Feb 5 13:23:50 2023 +0100

    gnu: imv: Record absolute file name of 'imv' script.
    
    * gnu/packages/image-viewers.scm (imv)[arguments]: Fix the 'imv-dir'
    script in the 'record-absolute-file-names' phase.
    
    Signed-off-by: Leo Famulari <leo@famulari.name>
---
 gnu/packages/image-viewers.scm | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/image-viewers.scm b/gnu/packages/image-viewers.scm
index 02e25aee5f..1879b9949c 100644
--- a/gnu/packages/image-viewers.scm
+++ b/gnu/packages/image-viewers.scm
@@ -767,10 +767,12 @@ displayed in a terminal.")
                (add-after 'install 'record-absolute-file-names
                  (lambda _
                    ;; 'imv' is a script that execs 'imv-x11' or 'imv-wayland'.
                    ;; Record their absolute file name.
                    (let ((bin (string-append #$output "/bin")))
                      (substitute* (string-append bin "/imv")
-                       (("imv-") (string-append bin "/imv-")))))))))
+                       (("imv-") (string-append bin "/imv-")))
+                     (substitute* (string-append bin "/imv-dir")
+                       (("imv") (string-append bin "/imv")))))))))
     (native-inputs
      (list asciidoc
            pkg-config))
@@ -767,10 +767,12 @@ displayed in a terminal.")
                  (lambda _
                    ;; 'imv' is a script that execs 'imv-x11' or 'imv-wayland'.
-                   ;; Record their absolute file name.
+                   ;; 'imv-dir' execs 'imv'. Record their absolute file names.
                    (let ((bin (string-append #$output "/bin")))
                      (substitute* (string-append bin "/imv")



reply via email to

[Prev in Thread] Current Thread [Next in Thread]